@@ -1,13 +1,14 @@
 from six import python_2_unicode_compatible
 
-from quickbooks.objects.detailline import SalesItemLine, SubtotalLine, DiscountLine, DescriptionLine, DetailLine
+from quickbooks.objects.detailline import SalesItemLine, SubtotalLine, DiscountLine, DescriptionOnlyLine, DetailLine
 from .base import Address, EmailAddress, Ref, CustomField, CustomerMemo, QuickbooksManagedObject, \
     LinkedTxnMixin, QuickbooksTransactionEntity
 from .tax import TxnTaxDetail
+from ..mixins import DeleteMixin
 
 
 @python_2_unicode_compatible
-class CreditMemo(QuickbooksTransactionEntity, QuickbooksManagedObject, LinkedTxnMixin):
+class CreditMemo(DeleteMixin, QuickbooksTransactionEntity, QuickbooksManagedObject, LinkedTxnMixin):
     """
     QBO definition: The CreditMemo is a financial transaction representing a refund or credit of payment or part
     of a payment for goods or services that have been sold.
@@ -37,7 +38,7 @@ class CreditMemo(QuickbooksTransactionEntity, QuickbooksManagedObject, LinkedTxn
         "SalesItemLineDetail": SalesItemLine,
         "SubTotalLineDetail": SubtotalLine,
         "DiscountLineDetail": DiscountLine,
-        "DescriptionLineDetail": DescriptionLine
+        "DescriptionLineDetail": DescriptionOnlyLine
     }
 
     qbo_object_name = "CreditMemo"
