@@ -6,8 +6,6 @@ from future.moves.urllib.parse import quote
 
 from quickbooks.objects import Bill, Invoice
 
-from intuitlib.client import AuthClient
-from quickbooks.client import QuickBooks
 from tests.integration.test_base import QuickbooksUnitTestCase
 
 try:
@@ -229,7 +227,7 @@ class UpdateMixinTest(QuickbooksUnitTestCase):
     def test_save_create(self, create_object):
         department = Department()
         department.save(qb=self.qb_client)
-        create_object.assert_called_once_with("Department", department.to_json())
+        create_object.assert_called_once_with("Department", department.to_json(), request_id=None)
 
     def test_save_create_with_qb(self):
         with patch.object(self.qb_client, 'create_object') as create_object:
@@ -244,7 +242,7 @@ class UpdateMixinTest(QuickbooksUnitTestCase):
         json = department.to_json()
 
         department.save(qb=self.qb_client)
-        update_object.assert_called_once_with("Department", json)
+        update_object.assert_called_once_with("Department", json, request_id=None)
 
     def test_save_update_with_qb(self):
         with patch.object(self.qb_client, 'update_object') as update_object:
